==> android-2.10.0-sources.jar: io/primer/android/payment/google/GooglePayFactory.kt <==
package io.primer.android.payment.google

import io.primer.android.PaymentMethod
import io.primer.android.data.payments.methods.mapping.PaymentMethodFactory
import io.primer.android.data.settings.PrimerSettings
import io.primer.android.utils.Either
import io.primer.android.utils.Failure
import io.primer.android.utils.PaymentUtils
import io.primer.android.utils.Success
import java.util.Currency

internal class GooglePayFactory(val settings: PrimerSettings) : PaymentMethodFactory {

    override fun build(): Either<PaymentMethod, Exception> {
        val amount: Int
        try {
            amount = settings.currentAmount
        } catch (e: IllegalArgumentException) {
            return Failure(Exception(e.message))
        }

        if (amount == 0) {
            return Failure(Exception("Amount is zero"))
        }

        if (settings.order.countryCode == null) {
            return Failure(Exception("Country code is null"))
        }

        val currency: Currency

        try {
            currency = Currency.getInstance(settings.currency)
        } catch (e: IllegalArgumentException) {
            return Failure(Exception(e.message))
        }

        val googlePay = GooglePay(
            settings.paymentMethodOptions.googlePayOptions.merchantName,
            PaymentUtils.minorToAmount(settings.currentAmount, currency).toString(),
            settings.order.countryCode.toString(),
            currency.currencyCode,
            settings.paymentMethodOptions.googlePayOptions.allowedCardNetworks,
            settings.paymentMethodOptions.googlePayOptions.buttonStyle,
        )

        return Success(googlePay)
    }
}

==> android-2.26.1-sources.jar: io/primer/android/payment/google/GooglePayFactory.kt <==
package io.primer.android.payment.google

import io.primer.android.PaymentMethod
import io.primer.android.data.configuration.datasource.LocalConfigurationDataSource
import io.primer.android.data.payments.methods.mapping.PaymentMethodFactory
import io.primer.android.data.settings.PrimerSettings
import io.primer.android.utils.Either
import io.primer.android.utils.Failure
import io.primer.android.utils.PaymentUtils
import io.primer.android.utils.Success
import java.util.Currency

internal class GooglePayFactory(
    private val settings: PrimerSettings,
    private val localConfigurationDataSource: LocalConfigurationDataSource
) : PaymentMethodFactory {

    override fun build(): Either<PaymentMethod, Exception> {
        if (settings.order.countryCode == null) {
            return Failure(Exception("Country code is null"))
        }

        val currency: Currency

        try {
            currency = Currency.getInstance(settings.currency)
        } catch (e: IllegalArgumentException) {
            return Failure(Exception(e.message))
        }

        val googlePay = GooglePay(
            settings.paymentMethodOptions.googlePayOptions.merchantName,
            PaymentUtils.minorToAmount(settings.currentAmount, currency).toString(),
            settings.order.countryCode.toString(),
            currency.currencyCode,
            localConfigurationDataSource.getConfiguration().clientSession
                .paymentMethod?.orderedAllowedCardNetworks.orEmpty().intersect(
                    GooglePay.allowedCardNetworks
                ).toList(),
            settings.paymentMethodOptions.googlePayOptions.buttonStyle,
            settings.paymentMethodOptions.googlePayOptions.captureBillingAddress
        )

        return Success(googlePay)
    }
}
